Сменить язык

[![en](https://img.shields.io/badge/lang-en-red.svg)](https://github.com/04Maksimka/AstraGeek/blob/main/README.md)
[![ru](https://img.shields.io/badge/lang-ru-green.svg)](https://github.com/04Maksimka/AstraGeek/blob/main/README.ru.md)

# 🌌 AstraGeek. Звездный атлас

Проект онлайн-школы астрономии AstraGeek.
Здесь вы можете найти программное обеспечение для создания звездных карт.

На [сайте](https://skychart.astrageek.ru/) проекта AstraGeek вы можете создавать классические небесные диаграммы и карты звездного неба.

Также посетите сайт [astrageek.ru](https://astrageek.ru/), где вы найдете обучающие видео по астрономии и на смежные темы.

---

## План выпуска. **Текущая версия 0.2**

В процессе разработки интерфейс использования программного обеспечения для генерации карт через командную строку. Пока он разрабатывается, Вы можете использовать готовые сгенерированные карты случайных областей неба или пользоваться исходным кодом самостоятельно в рамках лицензии. 

0.1 Стереографическая проекция звездного неба (скайчарт) в соответствии с заданным географическим положением и временем. Также доступно отображение планет, больших кругов (эклиптики, небесного и галактического экватора). Доступно отображение горизонтальной и экваториальной сетки координат, сторон света. В качестве примера, в процессе разработки мы ориентировались на скайчарты с [этого сайта](https://skyatlas.app/star-charts/).

0.2 Построение отдельных участков неба в режиме камеры-обскуры. Этот режим предоставляет все те же возможности, что и в 0.1, но в другой проекции неба. Можно отобразить созвездия по названию, задать поле зрения, угол поворота камеры и размер полученного изображения.

0.3 Анимация прохождения планет (gif и статические последовательности изображений)

0.4 Прецессия вращения Земли

---

## Особенности

1. Классическая стереографическая проекция всего неба, доступного к наблюдению в указанном месте и в указанное время.
2. Режим камеры-обскуры для определенной небольшой области неба в указанном направлении (выбранное созвездие)
3. Можно добавлять различные дополнительные опорные элементы: координатные сетки, большие координатные круги (эклиптика, галактический и небесный экватор), стороны света, точку зенита и небесные полюса.
4. Можно добавить к изображению контуры всех видимых созвездий или отдельных выбранных созвездий, а также названия каждого видимого или избранного созвездия.

---

## Примеры

Пример режима камеры-обскуры (без условных обозначений):

<img width="1246" height="838" alt="изображение" src="https://github.com/user-attachments/assets/c73f3266-20ec-4617-b763-e1647df4d081" />

Полный файл: [pinhole_local_logo.pdf](https://github.com/user-attachments/files/24474532/pinhole_local_logo.pdf)


Пример режима стереографической проекции (без условных обозначений):

<img width="1086" height="1065" alt="изображение" src="https://github.com/user-attachments/assets/dfd66621-1e12-43cb-b6c1-06ad275bdd12" />

Полный файл: [polar_scatter_local_logo.pdf](https://github.com/user-attachments/files/24474544/polar_scatter_local_logo.pdf)

---

## Как использовать

Вы можете пользоваться готовыми наборами карт звездного неба, которые мы уже сгенерировали. Для этого:

1. Перейдите по [ссылке](https://drive.google.com/drive/folders/1AfBc7pkqLH_65TMAeXvpzzzqrLcVKNFO?usp=sharing)
2. Скачайте архивы pinhole_samples.zip и samples.zip с картами режима камеры-обскуры и скайчартами соответственно

Внутри каждой папки находятся сгруппированные по номерам карты звездного неба с заданиями. 

Внутри папки pinhole_samples находятся две папки:

1. **constellations**  - карты с конкретным центральным созвездием, для каждого из 88 созвездий
2. **random_sky** - карты с произвольным центральным созвездием, 10 примеров

Внутри папки samples сгруппированы скайчарты на произвольные дату и место

Каждая группа состоит из трех файлов карт:

1. Для ученика без планет, пустой классический скайчарт - _student.pdf_
2. Для ученика с планетами - _student_with_planets.pdf_
3. Для учителя - _teacher.pdf_

Каждый файл состоит из двух страниц: на первой находятся задания к карте, на второй непосредственно сама карта.

Файл для ученика содержит только задания и "голую" карту. Файл для учителя содержит все ответы и заполненную карту

---

Если Вы хотите генерировать карты самостоятельно, то следуйте следующей инструкции (удобный процесс пока в разработке):

1. Выберите необходимый тип проекции:

    1. Если вы хотите, чтобы в данном месте в данный момент времени был доступен вид всего неба, выберите **режим стереографической проекции**
    2. Если вы хотите увидеть определенный небольшой участок неба, как если бы вы наблюдали за ним своими глазами или в небольшой телескоп, выберите **режим камеры-обскуры**

2. Настройте каталог и проектор:

    1. Установите местоположение (широту и долготу) и местное время наблюдения.
    2. Установите пределы видимой звездной величины.
    3. Используйте флаги, чтобы задать дополнительные функции и свойства, которые вы хотите отобразить. Или, для образовательных целей, вы можете использовать готовые наборы для учителя и ученика (смотрите раздел ниже) 

3. Получите полученные звездные карты

Пример использования:

```cmd
./....
```

---

## Документация

На [этом сайте](https://04maksimka.github.io/AstraGeek/) вы скоро сможете найти полную техническую документацию проекта.

| Раздел | Ссылка                                                                                              |
| ---------------- |-----------------------------------------------------------------------------------------------------|
| Узнать больше | [Пользовательская документация](https://github.com/04Maksimka/AstraGeek/blob/main/DOCUMENTATION.md) |
| Проект на GitHub| [Репозиторий на GitHub](https://github.com/04Maksimka/AstraGeek)                                    |
| Обратная связь | [Issue](https://github.com/04Maksimka/AstraGeek/issues/new)                                         |

---






